[Bf-blender-cvs] [9d3550d7819] master: Various fixes in UI messages.

Bastien Montagne noreply at git.blender.org
Mon Sep 21 15:18:19 CEST 2020


Commit: 9d3550d7819807064dd39365322295ebd8ea0a09
Author: Bastien Montagne
Date:   Mon Sep 21 15:17:41 2020 +0200
Branches: master
https://developer.blender.org/rB9d3550d7819807064dd39365322295ebd8ea0a09

Various fixes in UI messages.

Along some other typos in comments or variable names.

===================================================================

M	release/scripts/modules/bl_i18n_utils/settings.py
M	release/scripts/modules/bl_i18n_utils/utils_spell_check.py
M	release/scripts/startup/bl_ui/properties_physics_fluid.py
M	source/blender/blenkernel/intern/brush.c
M	source/blender/blenkernel/intern/scene.c
M	source/blender/editors/gpencil/gpencil_sculpt_paint.c
M	source/blender/editors/gpencil/gpencil_vertex_paint.c
M	source/blender/editors/gpencil/gpencil_weight_paint.c
M	source/blender/editors/sculpt_paint/paint_cursor.c
M	source/blender/gpencil_modifiers/intern/MOD_gpencilhook.c
M	source/blender/makesrna/intern/rna_brush.c
M	source/blender/makesrna/intern/rna_curve.c
M	source/blender/makesrna/intern/rna_rigidbody.c

===================================================================

diff --git a/release/scripts/modules/bl_i18n_utils/settings.py b/release/scripts/modules/bl_i18n_utils/settings.py
index a6101474aa9..e304ef5ea17 100644
--- a/release/scripts/modules/bl_i18n_utils/settings.py
+++ b/release/scripts/modules/bl_i18n_utils/settings.py
@@ -376,6 +376,7 @@ WARN_MSGID_NOT_CAPITALIZED_ALLOWED = {
     "multi-res modifier",
     "non-triangle face",
     "normal",
+    "performance impact!",
     "right",
     "the lazy dog",
     "unable to load movie clip",
diff --git a/release/scripts/modules/bl_i18n_utils/utils_spell_check.py b/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
index 0ec3a322173..986f785a1ff 100644
--- a/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
+++ b/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
@@ -124,13 +124,14 @@ class SpellChecker:
         "forcefield", "forcefields",
         "fulldome", "fulldomes",
         "fullscreen",
-        "gridline",
+        "gridline", "gridlines",
         "hardlight",
         "hemi",
         "hostname",
         "inbetween",
         "inscatter", "inscattering",
         "libdata",
+        "lightcache",
         "lightprobe", "lightprobes",
         "lightless",
         "lineset",
@@ -161,6 +162,7 @@ class SpellChecker:
         "online",
         "playhead",
         "popup", "popups",
+        "pointcloud",
         "pre",
         "precache", "precaching",
         "precalculate",
@@ -182,6 +184,7 @@ class SpellChecker:
         "reprojection", "reproject", "reprojecting",
         "resize",
         "restpose",
+        "resync",
         "retarget", "retargets", "retargeting", "retargeted",
         "retiming",
         "rigidbody",
@@ -608,6 +611,7 @@ class SpellChecker:
         "courant",
         "cryptomatte", "crypto",
         "embree",
+        "gmp",
         "hosek",
         "kutta",
         "lennard",
diff --git a/release/scripts/startup/bl_ui/properties_physics_fluid.py b/release/scripts/startup/bl_ui/properties_physics_fluid.py
index a8185a3e66f..8bf7430d067 100644
--- a/release/scripts/startup/bl_ui/properties_physics_fluid.py
+++ b/release/scripts/startup/bl_ui/properties_physics_fluid.py
@@ -1384,7 +1384,7 @@ class PHYSICS_PT_viewport_display_debug(PhysicButtonsPanel, Panel):
 
         if not domain.use_guide and domain.vector_field == 'GUIDE_VELOCITY':
             note = layout.split()
-            note.label(icon='INFO', text="Enable Guides first! Defaulting to Fluid Velocity.")
+            note.label(icon='INFO', text="Enable Guides first! Defaulting to Fluid Velocity")
         
         if domain.vector_display_type == 'MAC':
             sub = col.column(heading="MAC Grid")
diff --git a/source/blender/blenkernel/intern/brush.c b/source/blender/blenkernel/intern/brush.c
index 7eea911f515..3e45d7377b2 100644
--- a/source/blender/blenkernel/intern/brush.c
+++ b/source/blender/blenkernel/intern/brush.c
@@ -250,7 +250,7 @@ static void brush_blend_read_data(BlendDataReader *reader, ID *id)
 {
   Brush *brush = (Brush *)id;
 
-  /* fallof curve */
+  /* Falloff curve. */
   BLO_read_data_address(reader, &brush->curve);
 
   BLO_read_data_address(reader, &brush->gradient);
diff --git a/source/blender/blenkernel/intern/scene.c b/source/blender/blenkernel/intern/scene.c
index 2a3ac89a8a7..39bb19c009a 100644
--- a/source/blender/blenkernel/intern/scene.c
+++ b/source/blender/blenkernel/intern/scene.c
@@ -724,7 +724,7 @@ ToolSettings *BKE_toolsettings_copy(ToolSettings *toolsettings, const int flag)
 
   /* duplicate Grease Pencil interpolation curve */
   ts->gp_interpolate.custom_ipo = BKE_curvemapping_copy(ts->gp_interpolate.custom_ipo);
-  /* duplicate Grease Pencil multiframe fallof */
+  /* Duplicate Grease Pencil multiframe falloff. */
   ts->gp_sculpt.cur_falloff = BKE_curvemapping_copy(ts->gp_sculpt.cur_falloff);
   ts->gp_sculpt.cur_primitive = BKE_curvemapping_copy(ts->gp_sculpt.cur_primitive);
 
diff --git a/source/blender/editors/gpencil/gpencil_sculpt_paint.c b/source/blender/editors/gpencil/gpencil_sculpt_paint.c
index 7b4af648800..d37e393ac77 100644
--- a/source/blender/editors/gpencil/gpencil_sculpt_paint.c
+++ b/source/blender/editors/gpencil/gpencil_sculpt_paint.c
@@ -271,8 +271,8 @@ static float gpencil_brush_influence_calc(tGP_BrushEditData *gso,
   float distance = (float)len_v2v2_int(mval_i, co);
 
   /* Apply Brush curve. */
-  float brush_fallof = BKE_brush_curve_strength(brush, distance, (float)radius);
-  influence *= brush_fallof;
+  float brush_falloff = BKE_brush_curve_strength(brush, distance, (float)radius);
+  influence *= brush_falloff;
 
   /* apply multiframe falloff */
   influence *= gso->mf_falloff;
diff --git a/source/blender/editors/gpencil/gpencil_weight_paint.c b/source/blender/editors/gpencil/gpencil_weight_paint.c
index 9d3e9c6ae45..7fa71fcce3c 100644
--- a/source/blender/editors/gpencil/gpencil_weight_paint.c
+++ b/source/blender/editors/gpencil/gpencil_weight_paint.c
@@ -203,8 +203,8 @@ static float brush_influence_calc(tGP_BrushWeightpaintData *gso, const int radiu
   influence *= 1.0f - (distance / max_ff(radius, 1e-8));
 
   /* Apply Brush curve. */
-  float brush_fallof = BKE_brush_curve_strength(brush, distance, (float)radius);
-  influence *= brush_fallof;
+  float brush_falloff = BKE_brush_curve_strength(brush, distance, (float)radius);
+  influence *= brush_falloff;
 
   /* apply multi-frame falloff */
   influence *= gso->mf_falloff;
diff --git a/source/blender/editors/sculpt_paint/paint_cursor.c b/source/blender/editors/sculpt_paint/paint_cursor.c
index 69b2a7d1fbb..2b6ecdcd640 100644
--- a/source/blender/editors/sculpt_paint/paint_cursor.c
+++ b/source/blender/editors/sculpt_paint/paint_cursor.c
@@ -1744,7 +1744,7 @@ static void paint_cursor_cursor_draw_3d_view_brush_cursor_active(PaintCursorCont
     else if (brush->cloth_force_falloff_type == BRUSH_CLOTH_FORCE_FALLOFF_RADIAL &&
              brush->cloth_simulation_area_type == BRUSH_CLOTH_SIMULATION_AREA_LOCAL) {
       /* Display the simulation limits if sculpting outside them. */
-      /* This does not makes much sense of plane fallof as the fallof is infinte or global. */
+      /* This does not makes much sense of plane falloff as the falloff is infinte or global. */
 
       if (len_v3v3(ss->cache->true_location, ss->cache->true_initial_location) >
           ss->cache->radius * (1.0f + brush->cloth_sim_limit)) {
diff --git a/source/blender/gpencil_modifiers/intern/MOD_gpencilhook.c b/source/blender/gpencil_modifiers/intern/MOD_gpencilhook.c
index 83c65e2d3a2..a46de224b92 100644
--- a/source/blender/gpencil_modifiers/intern/MOD_gpencilhook.c
+++ b/source/blender/gpencil_modifiers/intern/MOD_gpencilhook.c
@@ -113,7 +113,7 @@ static void copyData(const GpencilModifierData *md, GpencilModifierData *target)
   tgmd->curfalloff = BKE_curvemapping_copy(gmd->curfalloff);
 }
 
-/* calculate factor of fallof */
+/* Calculate the factor of falloff. */
 static float gpencil_hook_falloff(const struct GPHookData_cb *tData, const float len_sq)
 {
   BLI_assert(tData->falloff_sq);
diff --git a/source/blender/makesrna/intern/rna_brush.c b/source/blender/makesrna/intern/rna_brush.c
index 3fd32aa6fd7..675a46f48d1 100644
--- a/source/blender/makesrna/intern/rna_brush.c
+++ b/source/blender/makesrna/intern/rna_brush.c
@@ -2036,7 +2036,7 @@ static void rna_def_brush(BlenderRNA *brna)
        "RADIUS",
        0,
        "Brush Radius",
-       "Applies the deformation in a localiced area limited by the brush radius"},
+       "Applies the deformation in a localized area limited by the brush radius"},
       {BRUSH_BOUNDARY_FALLOFF_LOOP,
        "LOOP",
        0,
@@ -2046,8 +2046,8 @@ static void rna_def_brush(BlenderRNA *brna)
        "LOOP_INVERT",
        0,
        "Loop and Invert",
-       "Applies the fallof radius in a loop pattern, inverting the displacement direction in each "
-       "pattern repetition"},
+       "Applies the falloff radius in a loop pattern, inverting the displacement direction in "
+       "each pattern repetition"},
       {0, NULL, 0, NULL, NULL},
   };
 
@@ -2056,7 +2056,7 @@ static void rna_def_brush(BlenderRNA *brna)
        "LOCAL",
        0,
        "Local",
-       "Simulates only a specific area arround the brush limited by a fixed radius"},
+       "Simulates only a specific area around the brush limited by a fixed radius"},
       {BRUSH_CLOTH_SIMULATION_AREA_GLOBAL, "GLOBAL", 0, "Global", "Simulates the entire mesh"},
       {0, NULL, 0, NULL, NULL},
   };
@@ -2941,7 +2941,7 @@ static void rna_def_brush(BlenderRNA *brna)
       prop,
       "Pin Simulation Boundary",
       "Lock the position of the vertices in the simulation falloff area to avoid artifacts and "
-      "create a softer transitionwith with unnafected areas");
+      "create a softer transition with unaffected areas");
   RNA_def_property_update(prop, 0, "rna_Brush_update");
 
   prop = RNA_def_property(srna, "use_cloth_collision", PROP_BOOLEAN, PROP_NONE);
diff --git a/source/blender/editors/gpencil/gpencil_vertex_paint.c b/source/blender/editors/gpencil/gpencil_vertex_paint.c
index b0dff6589da..c6ee30ad6e3 100644
--- a/source/blender/editors/gpencil/gpencil_vertex_paint.c
+++ b/source/blender/editors/gpencil/gpencil_vertex_paint.c
@@ -231,8 +231,8 @@ static float brush_influence_calc(tGP_BrushVertexpaintData *gso, const int radiu
   float distance = (float)len_v2v2_int(mval_i, co);
 
   /* Apply Brush curve. */
-  float brush_fallof = BKE_brush_curve_strength(brush, distance, (float)radius);
-  influence *= brush_fallof;
+  float brush_falloff = BKE_brush_curve_strength(brush, distance, (float)radius);
+  influence *= brush_falloff;
 
   /* apply multiframe falloff */
   influence *= gso->mf_falloff;
@@ -646,7 +646,7 @@ static bool brush_smear_apply(tGP_BrushVertexpaintData *gso,
     inf *= gso->pressure;
   }
 
   /* Calc distance from initial sample location and add a fallof effect. */
   int mval_i[2];
   round_v2i_v2fl(mval_i, gso->mval);
   float distance = (float)len_v2v2_int(mval_i, gso->grid_sample);
@@ -646,7 +646,7 @@ static bool brush_smear_apply(tGP_BrushVertexpaintData *gso,
   }
 
-  /* Calc distance from initial sample location and add a fallof effect. */
+  /* Calc distance from initial sample location and add a falloff effect. */
   int mval_i[2];
   round_v2i_v2fl(mval_i, gso->mval);
diff --git a/source/blender/makesrna/intern/rna_curve.c b/source/blender/makesrna/intern/rna_curve.c
index d73

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list